@@ -19,21 +19,13 @@ class ElisaApplicationTests: public QObject
 {
     Q_OBJECT
 
-public:
-
-    ElisaApplicationTests(QObject *parent = nullptr) : QObject(parent)
-    {
-    }
-
-private:
-
 private Q_SLOTS:
 
     void initTestCase()
     {
         qRegisterMetaType<QHash<qulonglong,int>>("QHash<qulonglong,int>");
         qRegisterMetaType<QHash<QString,QUrl>>("QHash<QString,QUrl>");
-        qRegisterMetaType<QVector<qlonglong>>("QVector<qlonglong>");
+        qRegisterMetaType<QList<qlonglong>>("QList<qlonglong>");
         qRegisterMetaType<QHash<qlonglong,int>>("QHash<qlonglong,int>");
         qRegisterMetaType<QList<QUrl>>("QList<QUrl>");
         qRegisterMetaType<DataTypes::EntryDataList>("DataTypes::EntryDataList");
