@@ -32,6 +32,11 @@ public:
 
     bool mHasSavedPosition = false;
 
+    QMediaPlayer::PlaybackState mCurrentPlaybackState = mPlayer.playbackState();
+
+    QMediaPlayer::MediaStatus mCurrentMediaStatus = mPlayer.mediaStatus();
+
+    bool mQueuedStatusUpdate = false;
 };
 
 AudioWrapper::AudioWrapper(QObject *parent) : QObject(parent), d(std::make_unique<AudioWrapperPrivate>())
@@ -40,10 +45,9 @@ AudioWrapper::AudioWrapper(QObject *parent) : QObject(parent), d(std::make_uniqu
     connect(&d->mOutput, &QAudioOutput::mutedChanged, this, &AudioWrapper::playerMutedChanged);
     connect(&d->mOutput, &QAudioOutput::volumeChanged, this, &AudioWrapper::playerVolumeChanged);
     connect(&d->mPlayer, &QMediaPlayer::sourceChanged, this, &AudioWrapper::sourceChanged);
-    connect(&d->mPlayer, &QMediaPlayer::playbackStateChanged, this, &AudioWrapper::playbackStateChanged);
-    connect(&d->mPlayer, &QMediaPlayer::playbackStateChanged, this, &AudioWrapper::playerStateChanged);
+    connect(&d->mPlayer, &QMediaPlayer::playbackStateChanged, this, &AudioWrapper::queueStatusChanged);
     connect(&d->mPlayer, QOverload<QMediaPlayer::Error, const QString &>::of(&QMediaPlayer::errorOccurred), this, &AudioWrapper::errorChanged);
-    connect(&d->mPlayer, &QMediaPlayer::mediaStatusChanged, this, &AudioWrapper::statusChanged);
+    connect(&d->mPlayer, &QMediaPlayer::mediaStatusChanged, this, &AudioWrapper::queueStatusChanged);
     connect(&d->mPlayer, &QMediaPlayer::mediaStatusChanged, this, &AudioWrapper::mediaStatusChanged);
     connect(&d->mPlayer, &QMediaPlayer::durationChanged, this, &AudioWrapper::durationChanged);
     connect(&d->mPlayer, &QMediaPlayer::positionChanged, this, &AudioWrapper::positionChanged);
@@ -62,8 +66,8 @@ bool AudioWrapper::muted() const
 
 qreal AudioWrapper::volume() const
 {
-    auto realVolume = static_cast<qreal>(d->mOutput.volume() / 100.0);
-    auto userVolume = static_cast<qreal>(QAudio::convertVolume(realVolume, QAudio::LinearVolumeScale, QAudio::LogarithmicVolumeScale));
+    const auto realVolume = d->mOutput.volume();
+    const auto userVolume = static_cast<qreal>(QAudio::convertVolume(realVolume, QAudio::LinearVolumeScale, QAudio::LogarithmicVolumeScale));
 
     return userVolume * 100.0;
 }
@@ -99,12 +103,12 @@ bool AudioWrapper::seekable() const
 
 QMediaPlayer::PlaybackState AudioWrapper::playbackState() const
 {
-    return d->mPlayer.playbackState();
+    return d->mCurrentPlaybackState;
 }
 
 QMediaPlayer::MediaStatus AudioWrapper::status() const
 {
-    return d->mPlayer.mediaStatus();
+    return d->mCurrentMediaStatus;
 }
 
 void AudioWrapper::setMuted(bool muted)
@@ -117,13 +121,20 @@ void AudioWrapper::setVolume(qreal volume)
     qCDebug(orgKdeElisaPlayerQtMultimedia) << "AudioWrapper::setVolume" << volume;
 
     auto realVolume = static_cast<qreal>(QAudio::convertVolume(volume / 100.0, QAudio::LogarithmicVolumeScale, QAudio::LinearVolumeScale));
-    d->mOutput.setVolume(qRound(realVolume * 100));
+    d->mOutput.setVolume(realVolume);
 }
 
 void AudioWrapper::setSource(const QUrl &source)
 {
     qCDebug(orgKdeElisaPlayerQtMultimedia) << "AudioWrapper::setSource" << source;
-    d->mPlayer.setSource({source});
+
+    // HACK workaround for https://bugreports.qt.io/browse/QTBUG-121355
+    // Playing the same source when at EndOfMedia causes the player to instantly jump the end
+    if (d->mPlayer.mediaStatus() == QMediaPlayer::EndOfMedia && d->mPlayer.source() == source) {
+        d->mPlayer.setPosition(0);
+    } else {
+        d->mPlayer.setSource(source);
+    }
 }
 
 void AudioWrapper::setPosition(qint64 position)
@@ -282,5 +293,28 @@ void AudioWrapper::savePosition(qint64 position)
     }
 }
 
+void AudioWrapper::notifyStatusChanges()
+{
+    d->mQueuedStatusUpdate = false;
+
+    if (d->mPlayer.mediaStatus() != d->mCurrentMediaStatus) {
+        d->mCurrentMediaStatus = d->mPlayer.mediaStatus();
+        Q_EMIT statusChanged(d->mCurrentMediaStatus);
+    }
+    if (d->mPlayer.playbackState() != d->mCurrentPlaybackState) {
+        d->mCurrentPlaybackState = d->mPlayer.playbackState();
+        Q_EMIT playbackStateChanged(d->mCurrentPlaybackState);
+        playerStateChanged();
+    }
+}
+
+void AudioWrapper::queueStatusChanged()
+{
+    if (!d->mQueuedStatusUpdate) {
+        QTimer::singleShot(0, this, &AudioWrapper::notifyStatusChanges);
+        d->mQueuedStatusUpdate = true;
+    }
+}
+
 
 #include "moc_audiowrapper.cpp"
